@@ -25,19 +25,14 @@ class OpenStackNovajoin(Plugin):
             self.add_copy_spec("/var/log/novajoin/*.log")
 
     def postproc(self):
-        regexp = (r"(?i)password=(.*)")
+        regexp = r"(password|memcache_secret_key)=(.*)"
         self.do_file_sub("/etc/novajoin/join.conf", regexp,
-                         r"password=*********")
-        regexp = (r"(?i)memcache_secret_key=(.*)")
-        self.do_file_sub("/etc/novajoin/join.conf", regexp,
-                         r"password=*********")
+                         r"\1=*********")
 
 
 class RedHatNovajoin(OpenStackNovajoin, RedHatPlugin):
 
     packages = ('python-novajoin',)
 
-    def setup(self):
-        super(RedHatNovajoin, self).setup()
 
 # vim: set et ts=4 sw=4 :
