@@ -22,15 +22,17 @@ class Stratis(Plugin, RedHatPlugin):
     def setup(self):
         subcmds = [
             'pool list',
+            'pool list --stopped',
             'filesystem list',
             'blockdev list',
             'key list',
-            'daemon redundancy',
             'daemon version',
             'report engine_state_report',
+            'report managed_objects_report',
+            'report stopped_pools',
             '--version',
         ]
 
-        self.add_cmd_output(["stratis %s" % subcmd for subcmd in subcmds])
+        self.add_cmd_output([f"stratis {subcmd}" for subcmd in subcmds])
 
 # vim: set et ts=4 sw=4 :
